@@ -11,9 +11,11 @@ from ._imports_ import *
 from ._imports_ import __all__
 
 if not hasattr(_dash, 'development'):
-    print('Dash was not successfully imported. '
-          'Make sure you don\'t have a file '
-          'named \n"dash.py" in your current directory.', file=_sys.stderr)
+    print(
+        'Dash was not successfully imported. '
+        'Make sure you don\'t have a file '
+        'named \n"dash.py" in your current directory.',
+        file=_sys.stderr)
     _sys.exit(1)
 
 _basepath = _os.path.dirname(__file__)
@@ -28,13 +30,17 @@ _current_path = _os.path.dirname(_os.path.abspath(__file__))
 
 _this_module = _sys.modules[__name__]
 
+print(package_name)
 
 _js_dist = [
     {
-        'relative_package_path': 'dash_mp_components.min.js',
-        'external_url': 'https://unpkg.com/{0}@{2}/{1}/{1}.min.js'.format(
+        'relative_package_path':
+        'dash_mp_components.min.js',
+        'external_url':
+        'https://unpkg.com/{0}@{2}/{1}/{1}.min.js'.format(
             package_name, __name__, __version__),
-        'namespace': package_name
+        'namespace':
+        package_name
     },
     #{
     #    'relative_package_path': 'dash_mp_components.min.js.map',
@@ -46,7 +52,6 @@ _js_dist = [
 
 _css_dist = []
 
-
 for _component in __all__:
     setattr(locals()[_component], '_js_dist', _js_dist)
     setattr(locals()[_component], '_css_dist', _css_dist)
