@@ -2,26 +2,32 @@ from .CameraContext import CameraContext
 from .GraphComponent import GraphComponent
 from .JsonView import JsonView
 from .MatSidebar import MatSidebar
+from .Simple3DScene import Simple3DScene
 from .PeriodicContext import PeriodicContext
 from .PeriodicContextTable import PeriodicContextTable
 from .PeriodicElement import PeriodicElement
 from .PeriodicFilter import PeriodicFilter
 from .PeriodicTableInput import PeriodicTableInput
+from .MatMaterialsTable import MatMaterialsTable
+from .MatPrintViewContext import MatPrintViewContext
+from .MatSearchGrid import MatSearchGrid
 from .Search import Search
 from .SearchGrid import SearchGrid
-from .Simple3DScene import Simple3DScene
 
 __all__ = [
     "CameraContext",
     "GraphComponent",
     "JsonView",
     "MatSidebar",
+    "Simple3DScene",
     "PeriodicContext",
     "PeriodicContextTable",
     "PeriodicElement",
     "PeriodicFilter",
     "PeriodicTableInput",
+    "MatMaterialsTable",
+    "MatPrintViewContext",
+    "MatSearchGrid",
     "Search",
-    "SearchGrid",
-    "Simple3DScene"
+    "SearchGrid"
 ]
\ No newline at end of file
